scripts/install.py

branch
maintenance
changeset 8043
0acf98cd089a
parent 7924
8a96736d465e
parent 7960
e8fc383322f7
child 8142
43248bafe9b2
--- a/scripts/install.py	Sun Jan 17 13:53:08 2021 +0100
+++ b/scripts/install.py	Mon Feb 01 10:38:16 2021 +0100
@@ -3,10 +3,10 @@
 
 # Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6.
 
 """
-Installation script for the eric6 IDE and all eric6 related tools.
+Installation script for the eric IDE and all eric related tools.
 """
 
 import sys
@@ -143,7 +143,7 @@
     print("    --no-apis  don't install API files")
     print("    -b dir     where the binaries will be installed")
     print("               (default: {0})".format(platBinDir))
-    print("    -d dir     where eric6 python files will be installed")
+    print("    -d dir     where eric python files will be installed")
     print("               (default: {0})".format(modDir))
     print("    -f file    configuration file naming the various installation"
           " paths")
@@ -179,7 +179,7 @@
     print("'ericTranslationsDir', 'ericTemplatesDir', 'ericCodeTemplatesDir',")
     print("'ericOthersDir','bindir', 'mdir' and 'apidir.")
     print("These define the directories for the installation of the various"
-          " parts of eric6.")
+          " parts of eric.")
 
     exit(rcode)
 
@@ -387,7 +387,7 @@
     @param dst name of the destination directory
     @param filters list of filter pattern determining the files to be copied
     @param excludeDirs list of (sub)directories to exclude from copying
-    @keyparam excludePatterns list of filter pattern determining the files to
+    @param excludePatterns list of filter pattern determining the files to
         be skipped
     """
     if excludeDirs is None:
@@ -493,7 +493,7 @@
     try:
         from eric6config import getConfig
     except ImportError:
-        # eric6 wasn't installed previously
+        # eric wasn't installed previously
         return
     except SyntaxError:
         # an incomplete or old config file was found
@@ -698,7 +698,7 @@
     
     @param src source file name (string)
     @param dst destination file name or directory name (string)
-    @keyparam perm permissions to be set (integer)
+    @param perm permissions to be set (integer)
     """
     shutil.copy(src, dst)
     if os.path.isdir(dst):
@@ -744,7 +744,7 @@
             if cfg[key] and not os.path.isdir(cfg[key]):
                 os.makedirs(cfg[key])
         
         # copy the eric6 config file
         if distDir:
             shutilCopy(configName, cfg['mdir'])
             if os.path.exists(configName + 'c'):
@@ -754,7 +754,7 @@
             if os.path.exists(configName + 'c'):
                 shutilCopy(configName + 'c', modDir)
         
         # copy the various parts of eric6
         copyTree(
             eric6SourceDir, cfg['ericDir'],
             ['*.py', '*.pyc', '*.pyo', '*.pyw'],
@@ -1257,7 +1257,7 @@
     config = (
         """# -*- coding: utf-8 -*-\n"""
         """#\n"""
         """# This module contains the configuration of the individual eric6"""
         """ installation\n"""
         """#\n"""
         """\n"""
@@ -1314,7 +1314,7 @@
 
 def createInstallInfo():
     """
     Record information about the way eric6 was installed.
     """
     global createInstallInfoFile, installInfo, installCwd, cfg
     
@@ -1435,8 +1435,8 @@
     
     # perform dependency checks
     print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
-    if sys.version_info < (3, 5, 0):
-        print('Sorry, you must have Python 3.5.0 or higher.')
+    if sys.version_info < (3, 6, 0):
+        print('Sorry, you must have Python 3.6.0 or higher.')
         exit(5)
     
     try:
@@ -1632,7 +1632,7 @@
             for vers in BlackLists["sip"] + PlatformBlackLists["sip"]:
                 if vers == sipVersion:
                     print(
-                        'Sorry, sip version {0} is not compatible with eric6.'
+                        'Sorry, sip version {0} is not compatible with eric.'
                         .format(vers))
                     print('Please install another version.')
                     exit(3)
@@ -1658,7 +1658,7 @@
         # check for blacklisted versions
         for vers in BlackLists["PyQt5"] + PlatformBlackLists["PyQt5"]:
             if vers == pyqtVersion:
-                print('Sorry, PyQt version {0} is not compatible with eric6.'
+                print('Sorry, PyQt version {0} is not compatible with eric.'
                       .format(vers))
                 print('Please install another version.')
                 exit(4)
@@ -1691,7 +1691,7 @@
             if vers == scintillaVersion:
                 print(
                     'Sorry, QScintilla2 version {0} is not compatible with'
-                    ' eric6.'.format(vers))
+                    ' eric.'.format(vers))
                 print('Please install another version.')
                 exit(5)
     
@@ -1879,8 +1879,8 @@
     global createInstallInfoFile, installCwd
     global ignorePyqt5Tools
     
-    if sys.version_info < (3, 5, 0) or sys.version_info > (3, 99, 99):
-        print('Sorry, eric6 requires at least Python 3.5 for running.')
+    if sys.version_info < (3, 6, 0) or sys.version_info > (3, 99, 99):
+        print('Sorry, eric requires at least Python 3.6 for running.')
         exit(5)
     
     progName = os.path.basename(argv[0])
@@ -2044,7 +2044,7 @@
             py_compile.compile(configName,
                                dfile=os.path.join(modDir, "eric6config.py"))
         sys.stdout = sys.__stdout__
-    print("\nInstalling eric6 ...")
+    print("\nInstalling eric ...")
     res = installEric()
     
     if createInstallInfoFile:
@@ -3,10 +3,10 @@
 # Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the install script for eric6.
+# This is the install script for eric.
 
 """
@@ -744,7 +744,7 @@
                 os.makedirs(cfg[key])
         
-        # copy the eric6 config file
+        # copy the eric config file
         if distDir:
             shutilCopy(configName, cfg['mdir'])
@@ -754,7 +754,7 @@
                 shutilCopy(configName + 'c', modDir)
         
-        # copy the various parts of eric6
+        # copy the various parts of eric
         copyTree(
             eric6SourceDir, cfg['ericDir'],
@@ -1257,7 +1257,7 @@
         """# -*- coding: utf-8 -*-\n"""
         """#\n"""
-        """# This module contains the configuration of the individual eric6"""
+        """# This module contains the configuration of the individual eric"""
         """ installation\n"""
         """#\n"""
@@ -1314,7 +1314,7 @@
 def createInstallInfo():
     """
-    Record information about the way eric6 was installed.
+    Record information about the way eric was installed.
     """
     global createInstallInfoFile, installInfo, installCwd, cfg

eric ide

mercurial